@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/ec2/EC2_EXPORTS.h>
@@ -21,6 +11,7 @@
 #include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/ec2/model/ImageDiskContainer.h>
 #include <aws/ec2/model/ImportImageLicenseConfigurationRequest.h>
+#include <aws/ec2/model/TagSpecification.h>
 #include <utility>
 
 namespace Aws
@@ -369,8 +360,8 @@ namespace Model
 
 
     /**
-     * <p>An identifier for the AWS Key Management Service (AWS KMS) customer master
-     * key (CMK) to use when creating the encrypted AMI. This parameter is only
+     * <p>An identifier for the symmetric AWS Key Management Service (AWS KMS) customer
+     * master key (CMK) to use when creating the encrypted AMI. This parameter is only
      * required if you want to use a non-default CMK; if this parameter is not
      * specified, the default CMK for EBS is used. If a <code>KmsKeyId</code> is
      * specified, the <code>Encrypted</code> flag must also be set. </p> <p>The CMK
@@ -392,13 +383,14 @@ namespace Model
      * </li> </ul> <p>AWS parses <code>KmsKeyId</code> asynchronously, meaning that the
      * action you call may appear to complete even though you provided an invalid
      * identifier. This action will eventually report failure. </p> <p>The specified
-     * CMK must exist in the Region that the AMI is being copied to.</p>
+     * CMK must exist in the Region that the AMI is being copied to.</p> <p>Amazon EBS
+     * does not support asymmetric CMKs.</p>
      */
     inline const Aws::String& GetKmsKeyId() const{ return m_kmsKeyId; }
 
     /**
-     * <p>An identifier for the AWS Key Management Service (AWS KMS) customer master
-     * key (CMK) to use when creating the encrypted AMI. This parameter is only
+     * <p>An identifier for the symmetric AWS Key Management Service (AWS KMS) customer
+     * master key (CMK) to use when creating the encrypted AMI. This parameter is only
      * required if you want to use a non-default CMK; if this parameter is not
      * specified, the default CMK for EBS is used. If a <code>KmsKeyId</code> is
      * specified, the <code>Encrypted</code> flag must also be set. </p> <p>The CMK
@@ -420,13 +412,14 @@ namespace Model
      * </li> </ul> <p>AWS parses <code>KmsKeyId</code> asynchronously, meaning that the
      * action you call may appear to complete even though you provided an invalid
      * identifier. This action will eventually report failure. </p> <p>The specified
-     * CMK must exist in the Region that the AMI is being copied to.</p>
+     * CMK must exist in the Region that the AMI is being copied to.</p> <p>Amazon EBS
+     * does not support asymmetric CMKs.</p>
      */
     inline bool KmsKeyIdHasBeenSet() const { return m_kmsKeyIdHasBeenSet; }
 
     /**
-     * <p>An identifier for the AWS Key Management Service (AWS KMS) customer master
-     * key (CMK) to use when creating the encrypted AMI. This parameter is only
+     * <p>An identifier for the symmetric AWS Key Management Service (AWS KMS) customer
+     * master key (CMK) to use when creating the encrypted AMI. This parameter is only
      * required if you want to use a non-default CMK; if this parameter is not
      * specified, the default CMK for EBS is used. If a <code>KmsKeyId</code> is
      * specified, the <code>Encrypted</code> flag must also be set. </p> <p>The CMK
@@ -448,13 +441,14 @@ namespace Model
      * </li> </ul> <p>AWS parses <code>KmsKeyId</code> asynchronously, meaning that the
      * action you call may appear to complete even though you provided an invalid
      * identifier. This action will eventually report failure. </p> <p>The specified
-     * CMK must exist in the Region that the AMI is being copied to.</p>
+     * CMK must exist in the Region that the AMI is being copied to.</p> <p>Amazon EBS
+     * does not support asymmetric CMKs.</p>
      */
     inline void SetKmsKeyId(const Aws::String& value) { m_kmsKeyIdHasBeenSet = true; m_kmsKeyId = value; }
 
     /**
-     * <p>An identifier for the AWS Key Management Service (AWS KMS) customer master
-     * key (CMK) to use when creating the encrypted AMI. This parameter is only
+     * <p>An identifier for the symmetric AWS Key Management Service (AWS KMS) customer
+     * master key (CMK) to use when creating the encrypted AMI. This parameter is only
      * required if you want to use a non-default CMK; if this parameter is not
      * specified, the default CMK for EBS is used. If a <code>KmsKeyId</code> is
      * specified, the <code>Encrypted</code> flag must also be set. </p> <p>The CMK
@@ -476,13 +470,14 @@ namespace Model
      * </li> </ul> <p>AWS parses <code>KmsKeyId</code> asynchronously, meaning that the
      * action you call may appear to complete even though you provided an invalid
      * identifier. This action will eventually report failure. </p> <p>The specified
-     * CMK must exist in the Region that the AMI is being copied to.</p>
+     * CMK must exist in the Region that the AMI is being copied to.</p> <p>Amazon EBS
+     * does not support asymmetric CMKs.</p>
      */
     inline void SetKmsKeyId(Aws::String&& value) { m_kmsKeyIdHasBeenSet = true; m_kmsKeyId = std::move(value); }
 
     /**
-     * <p>An identifier for the AWS Key Management Service (AWS KMS) customer master
-     * key (CMK) to use when creating the encrypted AMI. This parameter is only
+     * <p>An identifier for the symmetric AWS Key Management Service (AWS KMS) customer
+     * master key (CMK) to use when creating the encrypted AMI. This parameter is only
      * required if you want to use a non-default CMK; if this parameter is not
      * specified, the default CMK for EBS is used. If a <code>KmsKeyId</code> is
      * specified, the <code>Encrypted</code> flag must also be set. </p> <p>The CMK
@@ -504,13 +499,14 @@ namespace Model
      * </li> </ul> <p>AWS parses <code>KmsKeyId</code> asynchronously, meaning that the
      * action you call may appear to complete even though you provided an invalid
      * identifier. This action will eventually report failure. </p> <p>The specified
-     * CMK must exist in the Region that the AMI is being copied to.</p>
+     * CMK must exist in the Region that the AMI is being copied to.</p> <p>Amazon EBS
+     * does not support asymmetric CMKs.</p>
      */
     inline void SetKmsKeyId(const char* value) { m_kmsKeyIdHasBeenSet = true; m_kmsKeyId.assign(value); }
 
     /**
-     * <p>An identifier for the AWS Key Management Service (AWS KMS) customer master
-     * key (CMK) to use when creating the encrypted AMI. This parameter is only
+     * <p>An identifier for the symmetric AWS Key Management Service (AWS KMS) customer
+     * master key (CMK) to use when creating the encrypted AMI. This parameter is only
      * required if you want to use a non-default CMK; if this parameter is not
      * specified, the default CMK for EBS is used. If a <code>KmsKeyId</code> is
      * specified, the <code>Encrypted</code> flag must also be set. </p> <p>The CMK
@@ -532,13 +528,14 @@ namespace Model
      * </li> </ul> <p>AWS parses <code>KmsKeyId</code> asynchronously, meaning that the
      * action you call may appear to complete even though you provided an invalid
      * identifier. This action will eventually report failure. </p> <p>The specified
-     * CMK must exist in the Region that the AMI is being copied to.</p>
+     * CMK must exist in the Region that the AMI is being copied to.</p> <p>Amazon EBS
+     * does not support asymmetric CMKs.</p>
      */
     inline ImportImageRequest& WithKmsKeyId(const Aws::String& value) { SetKmsKeyId(value); return *this;}
 
     /**
-     * <p>An identifier for the AWS Key Management Service (AWS KMS) customer master
-     * key (CMK) to use when creating the encrypted AMI. This parameter is only
+     * <p>An identifier for the symmetric AWS Key Management Service (AWS KMS) customer
+     * master key (CMK) to use when creating the encrypted AMI. This parameter is only
      * required if you want to use a non-default CMK; if this parameter is not
      * specified, the default CMK for EBS is used. If a <code>KmsKeyId</code> is
      * specified, the <code>Encrypted</code> flag must also be set. </p> <p>The CMK
@@ -560,13 +557,14 @@ namespace Model
      * </li> </ul> <p>AWS parses <code>KmsKeyId</code> asynchronously, meaning that the
      * action you call may appear to complete even though you provided an invalid
      * identifier. This action will eventually report failure. </p> <p>The specified
-     * CMK must exist in the Region that the AMI is being copied to.</p>
+     * CMK must exist in the Region that the AMI is being copied to.</p> <p>Amazon EBS
+     * does not support asymmetric CMKs.</p>
      */
     inline ImportImageRequest& WithKmsKeyId(Aws::String&& value) { SetKmsKeyId(std::move(value)); return *this;}
 
     /**
-     * <p>An identifier for the AWS Key Management Service (AWS KMS) customer master
-     * key (CMK) to use when creating the encrypted AMI. This parameter is only
+     * <p>An identifier for the symmetric AWS Key Management Service (AWS KMS) customer
+     * master key (CMK) to use when creating the encrypted AMI. This parameter is only
      * required if you want to use a non-default CMK; if this parameter is not
      * specified, the default CMK for EBS is used. If a <code>KmsKeyId</code> is
      * specified, the <code>Encrypted</code> flag must also be set. </p> <p>The CMK
@@ -588,7 +586,8 @@ namespace Model
      * </li> </ul> <p>AWS parses <code>KmsKeyId</code> asynchronously, meaning that the
      * action you call may appear to complete even though you provided an invalid
      * identifier. This action will eventually report failure. </p> <p>The specified
-     * CMK must exist in the Region that the AMI is being copied to.</p>
+     * CMK must exist in the Region that the AMI is being copied to.</p> <p>Amazon EBS
+     * does not support asymmetric CMKs.</p>
      */
     inline ImportImageRequest& WithKmsKeyId(const char* value) { SetKmsKeyId(value); return *this;}
 
@@ -828,6 +827,47 @@ namespace Model
      */
     inline ImportImageRequest& AddLicenseSpecifications(ImportImageLicenseConfigurationRequest&& value) { m_licenseSpecificationsHasBeenSet = true; m_licenseSpecifications.push_back(std::move(value)); return *this; }
 
+
+    /**
+     * <p>The tags to apply to the image being imported.</p>
+     */
+    inline const Aws::Vector<TagSpecification>& GetTagSpecifications() const{ return m_tagSpecifications; }
+
+    /**
+     * <p>The tags to apply to the image being imported.</p>
+     */
+    inline bool TagSpecificationsHasBeenSet() const { return m_tagSpecificationsHasBeenSet; }
+
+    /**
+     * <p>The tags to apply to the image being imported.</p>
+     */
+    inline void SetTagSpecifications(const Aws::Vector<TagSpecification>& value) { m_tagSpecificationsHasBeenSet = true; m_tagSpecifications = value; }
+
+    /**
+     * <p>The tags to apply to the image being imported.</p>
+     */
+    inline void SetTagSpecifications(Aws::Vector<TagSpecification>&& value) { m_tagSpecificationsHasBeenSet = true; m_tagSpecifications = std::move(value); }
+
+    /**
+     * <p>The tags to apply to the image being imported.</p>
+     */
+    inline ImportImageRequest& WithTagSpecifications(const Aws::Vector<TagSpecification>& value) { SetTagSpecifications(value); return *this;}
+
+    /**
+     * <p>The tags to apply to the image being imported.</p>
+     */
+    inline ImportImageRequest& WithTagSpecifications(Aws::Vector<TagSpecification>&& value) { SetTagSpecifications(std::move(value)); return *this;}
+
+    /**
+     * <p>The tags to apply to the image being imported.</p>
+     */
+    inline ImportImageRequest& AddTagSpecifications(const TagSpecification& value) { m_tagSpecificationsHasBeenSet = true; m_tagSpecifications.push_back(value); return *this; }
+
+    /**
+     * <p>The tags to apply to the image being imported.</p>
+     */
+    inline ImportImageRequest& AddTagSpecifications(TagSpecification&& value) { m_tagSpecificationsHasBeenSet = true; m_tagSpecifications.push_back(std::move(value)); return *this; }
+
   private:
 
     Aws::String m_architecture;
@@ -868,6 +908,9 @@ namespace Model
 
     Aws::Vector<ImportImageLicenseConfigurationRequest> m_licenseSpecifications;
     bool m_licenseSpecificationsHasBeenSet;
+
+    Aws::Vector<TagSpecification> m_tagSpecifications;
+    bool m_tagSpecificationsHasBeenSet;
   };
 
 } // namespace Model
